@@ -3,8 +3,6 @@ test_that("Creating a Dockerfile works as expected", {
   if (!interactive()) {
     skip("Tests only run interactively")
   }
-
-  system("docker system prune -a --force")
   
   if (file.exists(here::here("examples/simple/Dockerfile"))) {
     file.remove(here::here("examples/simple/Dockerfile"))
@@ -14,7 +12,10 @@ test_that("Creating a Dockerfile works as expected", {
   }
   # Create the Dockerfile
   dock <- suppressWarnings({
-    create(project = here::here("examples/simple"), FROM = "rocker/r-ver")
+    create(
+      project = here::here("examples/simple"),
+      FROM = paste0("posit/r-base:", R.version$major, ".", R.version$minor, "-opensuse156")
+    )
   })
   # Read the lockfile
   lockfile <- renv::lockfile_read(here::here("examples/simple/renv.lock"))
